@@ -14,7 +14,7 @@
 from django.urls import path
 from django.urls import include
 from rest_framework.routers import DefaultRouter
-from coffee_price.lib import services
+from coffee_price.api import services
 
 routers = DefaultRouter()
 
